==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/taf/v20200210/models/RecognizeEffectiveFlowRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.taf.v20200210.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class RecognizeEffectiveFlowRequest extends AbstractModel{

    /**
    * 业务入参
    */
    @SerializedName("BusinessSecurityData")
    @Expose
    private InputRecognizeEffectiveFlow BusinessSecurityData;

    /**
     * Get 业务入参 
     * @return BusinessSecurityData 业务入参
     */
    public InputRecognizeEffectiveFlow getBusinessSecurityData() {
        return this.BusinessSecurityData;
    }

    /**
     * Set 业务入参
     * @param BusinessSecurityData 业务入参
     */
    public void setBusinessSecurityData(InputRecognizeEffectiveFlow BusinessSecurityData) {
        this.BusinessSecurityData = BusinessSecurityData;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "BusinessSecurityData.", this.BusinessSecurityData);

    }
}

==> tencentcloud-sdk-java-3.1.264-sources.jar: com/tencentcloudapi/taf/v20200210/models/RecognizeEffectiveFlowRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.taf.v20200210.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class RecognizeEffectiveFlowRequest extends AbstractModel{

    /**
    * 业务入参
    */
    @SerializedName("BusinessSecurityData")
    @Expose
    private InputRecognizeEffectiveFlow BusinessSecurityData;

    /**
     * Get 业务入参 
     * @return BusinessSecurityData 业务入参
     */
    public InputRecognizeEffectiveFlow getBusinessSecurityData() {
        return this.BusinessSecurityData;
    }

    /**
     * Set 业务入参
     * @param BusinessSecurityData 业务入参
     */
    public void setBusinessSecurityData(InputRecognizeEffectiveFlow BusinessSecurityData) {
        this.BusinessSecurityData = BusinessSecurityData;
    }

    public RecognizeEffectiveFlowRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public RecognizeEffectiveFlowRequest(RecognizeEffectiveFlowRequest source) {
        if (source.BusinessSecurityData != null) {
            this.BusinessSecurityData = new InputRecognizeEffectiveFlow(source.BusinessSecurityData);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "BusinessSecurityData.", this.BusinessSecurityData);

    }
}
